@@ -62,24 +62,25 @@ class Message:
         return await self.channel.kickMember(self.author)
 
     async def __sendFile(self, data, w, h, datatype):
-        path, key, url = await self.__http.upload(data, "image/jpeg", self.author)
-        return await self.channel.forwardChat(
+        path, key, url = await self.__http.upload(data, datatype, self.author)
+
+        return await self.channel.sendChat(
             "",
             json.dumps(
                 {
-                    "thumbnailUrl": url,
-                    "thumbnailHeight": w,
-                    "thumbnailWidth": h,
+                    # "thumbnailUrl": url,
+                    # "thumbnailHeight": w,
+                    # "thumbnailWidth": h,
                     "url": url,
                     "k": key,
-                    "cs": hashlib.sha1(data).hexdigest().upper(),
-                    "s": len(data),
                     "w": w,
                     "h": h,
                     "mt": datatype,
+                    "s": len(data)
                 }
             ),
             2,
+            att=True
         )
 
     async def send_file(self, _file, w, h):
