@@ -7,8 +7,25 @@ from Cryptodome.Hash import SHA1
 from Cryptodome.PublicKey.RSA import construct
 from Cryptodome.Signature import pss
 
+class File:
+    datatype = ""
+    def __init__(self, path):
+        self.path = path
 
+class Image(File):
+    datatype = "image/jpeg"
+    def __init__(self, path):
+        super().__init__(path)
 
+class Video(File):
+    datatype = "video/mp4"
+    def __init__(self, path):
+        super().__init__(path)
+
+class Audio(File):
+    datatype = "audio/m4a"
+    def __init__(self, path):
+        super().__init__(path)
 
 
 class Packet:
